#!/usr/bin/env python

from distutils.core import setup, Extension

long_description = """\
The 'arrayfrombuffer' package features support for Numeric Python
arrays whose contents are stored in buffer objects, including
memory-mapped files.  This has the following advantages:

- loading your array from a file is easy --- a module import and a
  single function call --- and doesn't use excessive amounts of
  memory.
- loading your array is quick; it doesn't need to be copied from one
  part of memory to another in order to be loaded.
- your array gets demand-loaded; parts you aren't using don't need to
  be in memory or in swap.
- under memory-pressure conditions, your array doesn't use up swap,
  and parts of it you haven't modified can be evicted from RAM without
  the need for a disk write
- your arrays can be bigger than your physical memory, up to the
  limitations imposed by your virtual memory address space and your
  OS; admittedly, this used to be a bigger deal when our PCs had 64
  mebibytes of RAM, 2 gibibytes of address space, and 4 gibibytes of
  disk space.  But on my laptop, which has 128 MiB of RAM and 256 MiB
  of swap, I added two 512-mebibyte arrays to produce a third one with
  the statement "Numeric.add(a, b, c)."  It took eleven minutes,
  though.
- when you modify your array, only the parts you modify get written
  back out to disk

In theory, you could also use this package for things like arrays in
memory shared between programs or arrays in distributed shared memory.
I haven't tried using it for those things, though.

Someone built a package called "Vmaps" that does something similar:
http://snafu.freedom.org/Vmaps/.  It was released 2002-01-22.
"""

setup(name="arrayfrombuffer",
      version="2",
      description="Creates Numeric arrays from buffer objects (such as mmap)",
      py_modules=["maparray"],
      ext_modules=[Extension("arrayfrombuffer", 
                             ['arrayfrombuffer.c'])],
      scripts=['addbigarrays.py'],
      author="Kragen Sitaker",
      author_email="kragen@pobox.com",
      url="http://pobox.com/~kragen/sw/arrayfrombuffer/",
      licence="BSD without the advertising clause",
      platforms=['Python'],
      long_description=long_description
      )
